%define url_ver %(echo %{version} | cut -d. -f1,2)

Name:		breezy
Summary:	Friendly distributed version control system
Version:	3.3.9
Release:	%mkrel 1
License:	GPLv2+
Group:		Development/Tools
Url:		https://www.breezy-vcs.org/
Source0:	https://launchpad.net/brz/%{url_ver}/%{version}/+download/breezy-%{version}.tar.gz
Patch50:	breezy-man-location.patch
Patch51:	breezy-pyo3.patch
BuildRequires:	pyproject-rpm-macros
BuildRequires:	python3-devel
BuildRequires:	rust-packaging
Obsoletes:	bzr < 3
Provides:	bzr = %{version}-%{release}
Provides:	brz = %{version}-%{release}

%description
Breezy (brz) is a decentralized revision control system, designed to be easy
for developers and end users alike.

By default, Breezy provides support for both the Bazaar and Git file formats.

%prep
%autosetup -p1
%cargo_prep

# Remove Cython generated .c files
find . -name '*_pyx.c' -delete

%generate_buildrequires
%cargo_generate_buildrequires
%pyproject_buildrequires

%build
export RUSTFLAGS="${RUSTFLAGS:-%{build_rustflags}}"
%pyproject_wheel
%make_build man1/brz.1

%install
%pyproject_install
%pyproject_save_files breezy

# symlinks
ln -s brz %{buildroot}%{_bindir}/bzr
ln -s git-remote-bzr %{buildroot}%{_bindir}/git-remote-brz

# man pages
install -Dpm644 man1/brz.1 %{buildroot}%{_mandir}/man1/brz.1
install -Dpm644 breezy/git/git-remote-bzr.1 %{buildroot}%{_mandir}/man1/git-remote-bzr.1
echo ".so man1/brz.1" > %{buildroot}%{_mandir}/man1/bzr.1
echo ".so man1/git-remote-bzr.1" > %{buildroot}%{_mandir}/man1/git-remote-brz.1

%find_lang %{name}

%files -f %{pyproject_files} -f %{name}.lang
%license COPYING*
%doc NEWS README.rst
%{_bindir}/brz
%{_bindir}/bzr-*-pack
%{_bindir}/bzr
%{_bindir}/git-remote-brz
%{_bindir}/git-remote-bzr
%{_mandir}/man1/brz.1*
%{_mandir}/man1/bzr.1*
%{_mandir}/man1/git-remote-brz.1*
%{_mandir}/man1/git-remote-bzr.1*


%changelog
* Wed Feb 26 2025 wally <wally> 3.3.9-1.mga10
+ Revision: 2153000
- new version 3.3.9
- rebuild for python3.13

* Sun Aug 25 2024 neoclust <neoclust> 3.3.8-1.mga10
+ Revision: 2091342
- New version 3.3.8

* Sun Apr 14 2024 wally <wally> 3.3.7-2.mga10
+ Revision: 2057455
- fix arm32 build

* Sun Apr 14 2024 wally <wally> 3.3.7-1.mga10
+ Revision: 2057446
- new version 3.3.7

* Wed Dec 27 2023 papoteur <papoteur> 3.3.2-4.mga10
+ Revision: 2022245
- rebuild again for python 3.12

* Sat Dec 09 2023 wally <wally> 3.3.2-3.mga10
+ Revision: 2016204
- rebuild for py3.12

* Thu Apr 27 2023 daviddavid <daviddavid> 3.3.2-2.mga9
+ Revision: 1955188
- add upstream patch to use newer pyo3
- use %%cargo_generate_buildrequires macro

* Sun Jan 22 2023 wally <wally> 3.3.2-1.mga9
+ Revision: 1934819
- new version 3.3.2

* Sun Nov 27 2022 wally <wally> 3.3.1-1.mga9
+ Revision: 1911709
- new version 3.3.1

* Mon Apr 11 2022 wally <wally> 3.2.2-1.mga9
+ Revision: 1848859
- new version 3.2.2

* Sun Mar 27 2022 umeabot <umeabot> 3.2.1-3.mga9
+ Revision: 1829321
- Mageia 9 Mass Rebuild

* Mon Feb 14 2022 mrambo3501 <mrambo3501> 3.2.1-2.mga9
+ Revision: 1775046
- fix files list
- rebuild for python-3.10

* Thu Jul 15 2021 wally <wally> 3.2.1-1.mga9
+ Revision: 1736122
- new version 3.2.1

* Sun May 09 2021 wally <wally> 3.2.0-1.mga9
+ Revision: 1722325
- new version 3.2.0

* Tue Apr 20 2021 daviddavid <daviddavid> 3.1.0-3.mga9
+ Revision: 1717594
- rebuild for arm

* Thu Mar 18 2021 neoclust <neoclust> 3.1.0-2.mga9
+ Revision: 1704363
- Rebuild against python 3.9

* Tue Jun 09 2020 wally <wally> 3.1.0-1.mga8
+ Revision: 1591484
- new version 3.1.0

* Tue Feb 18 2020 umeabot <umeabot> 3.0.2-2.mga8
+ Revision: 1541316
- Mageia 8 Mass Rebuild

* Sun Dec 22 2019 wally <wally> 3.0.2-1.mga8
+ Revision: 1469510
- imported package breezy

